# Шаблон проекта на C для $project_name

Этот шаблон имитирует структуру проектов на C в стиле Microsoft Visual Studio: отдельные файлы для объявлений, реализаций и точки входа. Он предназначен для быстрого старта разработки консольных приложений на C.

## Структура проекта

- `include/header.h`: Заголовочный файл, содержащий объявления функций и подключение стандартных библиотек.
- `src/source.c`: Файл с реализацией функций, импортирует `header.h`.
- `src/main.c`: Главный файл, содержащий функцию `main`, импортирует `header.h` и вызывает функции.
- `Makefile`: Файл для автоматизации сборки проекта.
- `.gitignore`: Исключает скомпилированные и временные файлы из Git.
- `.github/workflows/ci.yml`: Конфигурация для непрерывной интеграции (CI) через GitHub Actions.

## Установка

1. Убедитесь, что у вас установлен компилятор `gcc`. Для установки:
   - На Ubuntu/Debian: `sudo apt install build-essential`
   - На macOS: `xcode-select --install`
   - На Windows: Установите MinGW или используйте WSL.

2. Клонируйте репозиторий или распакуйте этот шаблон.

## Сборка и запуск

1. Соберите проект с помощью команды:
   ```bash
   make
   ```

2. Запустите приложение:
   ```bash
   ./program
   ```

   Вывод: `Сообщение: Тестовый запуск программы`

3. Для очистки скомпилированных файлов:
   ```bash
   make clean
   ```

## Структура и назначение файлов

- **`include/header.h`**:
  - Заголовочный файл, содержащий объявления функций и подключение необходимых библиотек (`stdio.h`, `string.h`).
  - Использует include-гварды (`#ifndef`, `#define`, `#endif`) для предотвращения повторного включения.
  - В текущем виде объявляет тестовую функцию `print_message`.

- **`src/source.c`**:
  - Файл с реализацией функций, объявленных в `header.h`.
  - Импортирует `header.h` для доступа к объявлениям.
  - Содержит реализацию тестовой функции `print_message`, которая выводит переданное сообщение в консоль.

- **`src/main.c`**:
  - Главный файл программы, содержащий функцию `main` — точку входа.
  - Импортирует `header.h` и вызывает функции, определённые в `source.c`.
  - В текущем виде вызывает `print_message` с тестовым сообщением.

- **`Makefile`**:
  - Автоматизирует процесс сборки проекта.
  - Компилирует исходные файлы (`main.c`, `source.c`) в объектные файлы и линкует их в исполняемый файл `program`.
  - Использует `gcc` с флагами `-Wall` (показывать все предупреждения) и `-g` (добавить отладочную информацию).
  - Поддерживает команды `make` (сборка) и `make clean` (удаление скомпилированных файлов).

- **`.gitignore`**:
  - Исключает скомпилированные файлы (например, `program`, `*.o`) и временные файлы (например, `.DS_Store`, `*.swp`) из Git.

- **`.github/workflows/ci.yml`**:
  - Настраивает непрерывную интеграцию через GitHub Actions.
  - Выполняет сборку проекта и запуск программы для проверки корректности.

## Настройка и расширение

- **Добавление новых функций**:
  1. Объявите функцию в `include/header.h`.
  2. Реализуйте её в `src/source.c`.
  3. Вызовите в `src/main.c`.
- **Добавление новых файлов**:
  1. Создайте новые `.c` файлы в `src/` и `.h` файлы в `include/`.
  2. Обновите `SRCS` в `Makefile`, добавив новые `.c` файлы.
- **Компиляция с другими параметрами**:
  - Измените `CFLAGS` в `Makefile`, например, добавьте `-O2` для оптимизации.

## Зависимости

- Требуется только компилятор `gcc` (или совместимый, например, `clang`).
- Никаких внешних библиотек для базового шаблона не нужно.


---
made by [**Floom**](https://github.com/Floom1)